<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="et">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Leet põhjusel</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Leet põhjusel välja lülitatud</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Katsete</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Lülitage aktiivsuse</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Leet põhjusel</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Leet põhjusel seadistused</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Leet põhjusel</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>Minu pered</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth seadistused</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Lülitatud välja</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Lülitage välja</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Lülitage käes</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth seadistused</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 ühendatud</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Ühendamine...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Lülitatud välja</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>%1 ühendatud</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Ühendamata</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Välja</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Värskendamine</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Näidet seadistused</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Näidet seadistused</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Värskendamine</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>Päikese</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>Pühapäev</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>Esmaspäev</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>Teisipaev</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>Kuupaev</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>Reede</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>Laupäev</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Lisa klahviplaan</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Kuupäev ja kellaaeg</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-tundeline aeg</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-tundeline aeg</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Kellaaja seaded</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Ava kalender</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Esmaspäev</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Teisipäev</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Kolmapäev</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Neljapäev</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Reede</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Laupäev</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Pühapäev</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>Esmaspäev</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>Teisipaev</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>Kuupaev</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>Reede</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>Laupäev</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>Pühapäev</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>Esmaspäev</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>Muid seadmeid</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>DND režiim</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>DND režiimi sätted</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Põhjesta</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Luba</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>DND režiim on lubatud</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>DND režiim on põhjestatud</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>DND režim</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Püha kõvamuse</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Püha kõvamuse on lubatud</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Püha kõvamuse on keelatud</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Kuva seaded</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>Püha kõvamuse</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Teemা</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Luba</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Keela</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Varm</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Tumed</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>Keela püha kõvamuse</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>Luba püha kõvamuse</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>Kuva seaded</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>Teemা: Varm</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>Teemা: Tumed</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>Teemা: Auto</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>Vaiksem mõju</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>Varm</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Tumed</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Teemা</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>Ühendusi ei ole</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>Teavikudavat</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Teavikud</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>Lülita DND režiim välja</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>Lülita DND režiim lõpule</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Teavik</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Seaded</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>Kõrge täpne</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>Keskmine</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Tõenäosusenergiahoiutaja</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation>Tasakaalustatud täpne</translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>Tõenäosus</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Tõenäosusteavikud</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Kapaktsiilus %1, jääb %2 minutit</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Kapaktsiilus %1, jääb %2 tundit ja %3 minutit</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Läbivõim %1, täis on %2 minutit pärast</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Läbivõim %1, täis on %2 tundit ja %3 minutit pärast</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Kapaktsiilus %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Läbivõim %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Kapaktsiilus %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Kapaktsiilus %1, täis</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>Kapaktsiilus %1, mitte läbivõim</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Bateri</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>Läbivõim, arvutatakse vajalikku läbivõimajõudu</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>Arvutatakse jäävast kasutamisajast</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>%1 minutit jääb</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>%1 tund %2 minut jääb</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>Ületöötamata</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>Põhjustatud</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>Ületöötamisel, %1 minut jääb põhjustamiseks</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>Ületöötamisel, %1 tund %2 minut jääb põhjustamiseks</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>Capaktsi %1, %2 tund jääb</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>%1 tund jääb</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>Ületöötamisel %1, %2 tund jääb põhjustamiseks</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>Ületöötamisel, %1 tund jääb põhjustamiseks</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>Müükse sätted</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Müsiik</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Tundmatu</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Sule arvuti</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Pöörduda</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibrieteneerimine</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Logi välja</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Müükse sätted</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Taaskäivita</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Värskendage ja lülituge välja</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Värskendage ja käivitage uuesti</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Lülituge välja</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Vaheta kasutaja</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>Täna</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>Lunaaline</translation>
    </message>
    <message>
        <source>y</source>
        <translation>a</translation>
    </message>
    <message>
        <source>m</source>
        <translation>k</translation>
    </message>
    <message>
        <source>d</source>
        <translation>p</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Pühapäev</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>Jan</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>Veeb</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>Märts</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>Aprill</translation>
    </message>
    <message>
        <source>May</source>
        <translation>Mai</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>Juuni</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>Juuli</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>August</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>Septembr</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>Oktobr</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>November</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>Detsembr</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Ava kalendri</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>esmaspäev</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>teisipäev</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>kolmapäev</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>neljapäev</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>reede</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>laupäev</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>pühapäev</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Lauluväli</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Väljamine</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Soovitised</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Heli</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Lülita äärmä</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Põhjeraha</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Soome seadistused</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Väljastamise seade puudub</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Ääne %1</translation>
    </message>
</context>
</TS>